/**********************************************************************************
 Copyright (C) 2010
 by 52 North Initiative for Geospatial Open Source Software GmbH

 Contact: Andreas Wytzisk 
 52 North Initiative for Geospatial Open Source Software GmbH
 Martin-Luther-King-Weg 24
 48155 Muenster, Germany
 info@52north.org

 This program is free software; you can redistribute and/or modify it under the
 terms of the GNU General Public License version 2 as published by the Free
 Software Foundation.

 This program is distributed WITHOUT ANY WARRANTY; even without the implied
 WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 General Public License for more details.

 You should have received a copy of the GNU General Public License along with this 
 program (see gnu-gplv2.txt). If not, write to the Free Software Foundation, Inc., 
 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or visit the Free Software
 Foundation web page, http://www.fsf.org.
 
 Created on: 02.11.2010
 *********************************************************************************/

package org.n52.spsMockup;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.HashMap;

import org.apache.log4j.Logger;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;

/**
 * @author Daniel Nüst (daniel.nuest@uni-muenster.de)
 * 
 */
public class SpsMockupResponse {

    public static final String CONTENT_TYPE_XML = "text/xml";

    private static final String CHARACTER_ENCODING = "UTF-8";
    
    private static final Logger log = Logger.getLogger(SpsMockupResponse.class);

    private XmlObject xml;

    /**
     * @param xml
     * @param replace 
     * @param pattern 
     */
    public SpsMockupResponse(XmlObject xml) {
        this.xml = xml;
    }

    /**
     * @return
     */
    public String getContentType() {
        return CONTENT_TYPE_XML;
    }

    /**
     * @return
     */
    public int getContentLength() {
        return getByteArray().length;
    }

    /**
     * @return
     */
    public byte[] getByteArray() {
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        XmlOptions options = new XmlOptions();
        options.setSaveNamespacesFirst();
        options.setSaveAggressiveNamespaces();
        options.setSavePrettyPrint();
        options.setCharacterEncoding(CHARACTER_ENCODING);
        
        HashMap<String, String> suggestedPrefixes = new HashMap<String, String>();
        suggestedPrefixes.putAll(XmlTools.FIXED_SUGGESTED_PREFIXES);
        suggestedPrefixes.put("http://www.opengis.net/sps/1.0",
                              "sps");

        try {
            this.xml.save(baos, options);
            byte[] bytes = baos.toByteArray();
            return bytes;
        }
        catch (IOException e) {
            log.fatal("Could not save xml to output stream!", e);
            return e.getMessage().getBytes();
        }
    }

}
